@@ -40,8 +40,12 @@ Auth_TUser::Auth_TUser(const char *s_acct, const char *s_pass, TF s_master)
   chans = NULL;
   dcc_cookie = NULL;
   dcc_active = FALSE;
-  security = sounds = TRUE;
-  usemsg = debug = FALSE;
+  security = TRUE;
+  usemsg = FALSE;
+#ifndef RPGSERV
+  sounds = TRUE;
+  debug = FALSE;
+#endif
   Util_Copy(acct, s_acct, ALLOC_ACCT);
   Util_Copy(pass, s_pass, ALLOC_PASS);
   *nick = 0;
