@@ -52,7 +52,7 @@ void Cmd_Actions_Root(void *ticket, int auth, const char *str)
 
   if (str==NULL) {
     Auth_CmdResult(ticket, auth,
-		   "Usage: do {say|action|nick|chan|quote|quit}");
+		   "Usage: do {say|action|msg|notice|nick|chan|quote|quit}");
     return ;
   }
   cmd = Util_Separate(&data, 32);
@@ -114,6 +114,46 @@ void Cmd_Actions_Root(void *ticket, int auth, const char *str)
     return ;
   }
 #endif
+  if (strcasecmp(cmd, "MSG")==0) {
+#ifdef RPGSERV
+#ifdef NO_USER_MSGNOTICE
+    if (auth<CMD_AUTH_MASTER) {
+      Auth_CmdResult(ticket, auth, "Access to this command is restricted.");
+      return ;
+    }
+#endif
+#endif
+    if (data == NULL) {
+      Auth_CmdResult(ticket, auth, "No target provided to send!");
+      return ;
+    }
+    cmd = Util_Separate(&data, 32);
+    if (cmd==NULL)
+      Auth_CmdResult(ticket, auth, "No message provided to send!");
+    else
+      IRC_MSG(cmd, data);
+    return ;
+  }
+  if (strcasecmp(cmd, "NOTICE")==0) {
+#ifdef RPGSERV
+#ifdef NO_USER_MSGNOTICE
+    if (auth<CMD_AUTH_MASTER) {
+      Auth_CmdResult(ticket, auth, "Access to this command is restricted.");
+      return ;
+    }
+#endif
+#endif
+    if (data == NULL) {
+      Auth_CmdResult(ticket, auth, "No target provided to send!");
+      return ;
+    }
+    cmd = Util_Separate(&data, 32);
+    if (cmd==NULL)
+      Auth_CmdResult(ticket, auth, "No message provided to send!");
+    else
+      IRC_Notice(cmd, data);
+    return ;
+  }
   if (strcasecmp(cmd, "QUOTE")==0) {
 #ifdef RPGSERV
     if (auth<CMD_AUTH_MASTER) {
