@@ -9,11 +9,7 @@
 #ifndef _CMD_ACTIONS_H_
 #define _CMD_ACTIONS_H_
 
-#ifdef RPGSERV
-void Cmd_Init();
-void Cmd_Cleanup();
-void Cmd_Root(void *, int, const char *);
-#else
+#ifndef RPGSERV
 void Cmd_actions_Init();
 void Cmd_Actions_Root(void *, int, const char *);
 #endif
