@@ -33,8 +33,8 @@ typedef struct tag_cmd_opts {
   char server[ALLOC_HOST];
   uint16 port;
   char quitmessage[ALLOC_BUFFER];
-  char userlist[ALLOC_BUFFER];
-  char logfile[ALLOC_BUFFER];
+  char *datadir;
+  char *logfile;
   char logtitle[ALLOC_BUFFER];
   TF logooc;
   TF nodesccmt;
